# Cantera

These scripts will run Cantera, create reactors with the specified conditions, and operate them. 

The resulting data winds up in `cantera_data/`. It consists of a set of simulation times and corresponding objects 
representing the gas's thermochemical state (specified completely by specifying TPX, temperature pressure composition).
With this list, post-processing scripts can create a Cantera gas object and set it to the exact condition of the gas 
in that reaction scenario.

Let's walk through a simple Cantera reactor setup - useful to test out whether Cantera works. 

The sequence of steps needed is as follows:
* Create a gas
* Set the initial gas state (TPX)
* Create a reactor
* Fill the reactor with the gas
* Create a reactor network
* Set specified parameters (timestep, total time, etc.)
* Advance the reactor network
* Save and plot results, if desired

Let's consider a mixture of ethylene and air autoigniting, simulated using the GRIMech 3.0 combustion mechanism.
The above steps are performed for this ethylene air mixture in the `EthyleneTest.py` script.

```
import cantera as ct

# Set the timestep and total simulation time
dt = 0.001
ttotal = 2.0

# Use GRI Mech 3.0
g = ct.Solution('gri30.xml')

# Set the initial state of the gas
g.TPX = 298.15 + 900, ct.one_atm, "CH4:4.0, O2:1.0, N2:3.762, H:0.00001"

# Create a reactor, and a reactor network to simulate it.
r = ct.Reactor(g)
n = ct.ReactorNet([r])

# This loop advances the reactor until we've reached the final time.
c = 0
t = dt
time_data = []
temp_data = []
while True:
    n.advance(t)

    time_data.append(t)
    temp_data.append(r.T)

    t = t + dt

    if(c % 10==0):
        print "Current reactor time:",t
    if t > ttotal:
        break

import matplotlib.pyplot as plt
plt.plot(time_data,temp_data)
plt.draw()
plt.show()

```

