import cantera as ct
import json
'''
Species reaction rate data

This script exports species reaction rate data directly to JSON format - no postprocessing intermediate.

This simulates ethylene autoignition for 1 second. 
However, because we're hacking this, and not doing postprocessing,
this will only output the state of the gas at one instant in time. 
Specifically, t = 0.2 s.

The JSON format is as follows:

[
    { 'species': 'C2H4', 'fwd_rxn_rate': 0.10, 'rev_rxn_rate': 0.25}
    { 'species': 'O2', 'fwd_rxn_rate': 1.93, 'rev_rxn_rate': 0.00}
]

A generic JSON data set looks like this:

[ 
  { 'letter': 'A', 'frequency': 0.08},
  { 'letter': 'B', 'frequency': 0.05}
]

'''

# Set the timestep and total simulation time
dt = 0.001
ttotal = 0.5

# Use GRI Mech 3.0
g = ct.Solution('gri30.xml')

# Set the initial state of the gas
g.TPX = 298.15 + 900, ct.one_atm, "CH4:4.0, O2:1.0, N2:3.762, H:0.00001"

# Create a reactor, and a reactor network to simulate it.
r = ct.Reactor(g)
n = ct.ReactorNet([r])

# This loop advances the reactor until we've reached the final time.
c = 0
t = dt
json_data = []
while True:
    n.advance(t)

    if(c==200):

        # Create species reaction data 
        fr = g.forward_rates_of_progress
        rr = g.reverse_rates_of_progress

        for sp in g.species_names:
            i = g.species_index(sp)
            dat = {}
            dat['species'] = sp
            dat['fwd_rxn_rate'] = fr[i]
            dat['rev_rxn_rate'] = rr[i]
            json_data.append(dat)

    t = t + dt
    c = c + 1

    if(c % 10==0):
        print "Current reactor time:",t

    if t > ttotal:
        break

# Note that we're writing data into d3_data/, not cantera_data/, 
# because we're skipping the usual Python postprocessing.
# Pantera classes and simple reactor and reactonet wrappers
# will clean this whole thing up. For now, jump into D3: 
# that's what we're really interested in, anyway.
with open('../d3_data/species_rxn_rates.json','w') as f:
    json.dump(json_data,f)

#import matplotlib.pyplot as plt
#plt.plot(time_data,temp_data)
#plt.draw()
#plt.show()

